Module: Google::Cloud::Parallelstore

Defined in:
lib/google/cloud/parallelstore.rb,
lib/google/cloud/parallelstore/version.rb

Constant Summary collapse

VERSION =
"2.0.1"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.parallelstore| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-parallelstore library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.


160
161
162
163
164
# File 'lib/google/cloud/parallelstore.rb', line 160

def self.configure
  yield ::Google::Cloud.configure.parallelstore if block_given?

  ::Google::Cloud.configure.parallelstore
end

.parallelstore(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for Parallelstore.

By default, this returns an instance of Google::Cloud::Parallelstore::V1::Parallelstore::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the Parallelstore service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the Parallelstore service. You can determine whether the method will succeed by calling parallelstore_available?.

About Parallelstore

Service describing handlers for resources Configures and manages parallelstore resources.

Parallelstore service.

The parallelstore.googleapis.com service implements the parallelstore API and defines the following resource model for managing instances:

  • The service works with a collection of cloud projects, named: /projects/*
  • Each project has a collection of available locations, named: /locations/*
  • Each location has a collection of instances named /instances/*.
  • Parallelstore instances are resources of the form: /projects/{project_id}/locations/{location_id}/instances/{instance_id}

Note that location_id must be a Google Cloud zone; for example:

  • projects/12345/locations/us-central1-c/instances/my-parallelstore-share


89
90
91
92
93
94
95
96
97
98
99
# File 'lib/google/cloud/parallelstore.rb', line 89

def self.parallelstore version: :v1, transport: :grpc, &block
  require "google/cloud/parallelstore/#{version.to_s.downcase}"

  package_name = Google::Cloud::Parallelstore
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Parallelstore.const_get(package_name).const_get(:Parallelstore)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.parallelstore_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the Parallelstore service is supported by the current client. If true, you can retrieve a client object by calling parallelstore. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the Parallelstore service, or if the versioned client gem needs an update to support the Parallelstore service.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/google/cloud/parallelstore.rb', line 113

def self.parallelstore_available? version: :v1, transport: :grpc
  require "google/cloud/parallelstore/#{version.to_s.downcase}"
  package_name = Google::Cloud::Parallelstore
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Parallelstore.const_get package_name
  return false unless service_module.const_defined? :Parallelstore
  service_module = service_module.const_get :Parallelstore
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end